@@ -1,2 +1,2 @@
-"""Allow users to access functions directly."""
+"""Gives users direct access to functions."""
 from lagrange.lagrange import lagrange, interpolate
